@@ -3,6 +3,7 @@ import pytz
 import logging
 import iso8601
 
+
 def utc_now():
     return pytz.utc.localize(datetime.utcnow())
 
@@ -21,7 +22,8 @@ def convert_iso_to_datetime(iso_str):
     # Converts ISO string into datetime obj
     logging.info(f"Converting from ISO to datetime obj...")
     datetime_obj = iso8601.parse_date(iso_str)
-    assert (isinstance(datetime_obj, datetime)), f"Failed to convert date into " \
-                                                                 f"datetime obj"
+    assert isinstance(datetime_obj, datetime), (
+        f"Failed to convert date into " f"datetime obj"
+    )
     logging.info(f"Datetime obj: {iso_str}")
-    return datetime_obj
\ No newline at end of file
+    return datetime_obj
